@@ -3,6 +3,11 @@
 #  __init__.py
 """
 Parser for MassHunter worklists.
+
+Only one function is defined here: :class:`~.read_worklist`,
+which reads the reads the given worklist file and returns
+a :class:`mh_utils.worklist_parser.classes.Worklist` file representing it.
+The other functions and classes must be imported from submodules of this package.
 """
 #
 #  Copyright (c) 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
@@ -23,12 +28,17 @@ Parser for MassHunter worklists.
 #  MA 02110-1301, USA.
 #
 
+# stdlib
+import os
+
 # 3rd party
 from domdf_python_tools.typing import PathLike
 
 # this package
 from mh_utils.worklist_parser.classes import Worklist
 
+__all__ = ["read_worklist"]
+
 
 def read_worklist(filename: PathLike) -> Worklist:
 	"""
@@ -37,4 +47,7 @@ def read_worklist(filename: PathLike) -> Worklist:
 	:param filename: The filename of the worklist.
 	"""
 
+	if not os.path.isfile(filename):
+		raise FileNotFoundError(f"'{filename}' does not exist.")
+
 	return Worklist.from_xml_file(filename)
